Method: IBRuby::Connection#initialize
- Defined in:
- lib/src.rb
#initialize(database, user, password, options) ⇒ Connection
This is the constructor for the Connection class.
Parameters
- database
-
A reference to the Database object to be connected to.
- user
-
A reference to the user name to be used in making the database connection. Defaults to nil.
- password
-
A reference to the user password to be used in making the connection. Defaults to nil.
- options
-
A Hash containing the options to be applied to the new connection. The hash will contain key/setting values, with the keys being based on the option constants defined within the Connection class. Individual options have differing value requirements. See the option documentation entries for further details. Defaults to nil.
Exceptions
- Exception
-
Generated whenever an invalid database is specified to the method or an issue occurs establishing the database connection.
244 245 |
# File 'lib/src.rb', line 244 def initialize(database, user, password, ) end |