Method: IBRuby::ResultSet#initialize

Defined in:
lib/src.rb

#initialize(connection, transaction, sql, dialect) ⇒ ResultSet

This is the constructor for the ResultSet object.

Parameters

connection

A reference to the Connection object that will be used to execute the SQL query.

transaction

A reference to the Transaction object that will be used in executing the SQL query.

sql

A reference to a String containing the SQL query that will be executed.

dialect

A reference to an integer containing the InterBase dialect to be used in executing the SQL statement.

Exceptions

IBRubyException

Generated whenever a non-query SQL statement is

specified, an invalid connection or transaction is
provided or a problem occurs executing the SQL
against the database.


706
707
# File 'lib/src.rb', line 706

def initialize(connection, transaction, sql, dialect)
end